@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -402,9 +402,9 @@ DimensionSettings.showLinearFormatWarning = function() {
     var appWin = EAction.getMainWindow();
     QMessageBox.warning(appWin,
                         qsTr("Unit / Format"),
-                        qsTr("The drawing unit must be 'Inch' to display dimension labels in "
-                             + "formats 'Architectural' or 'Engineering'. "
-                             + "Format changed to 'Decimal'."));
+                        qsTr("The drawing unit must be \"Inch\" to display dimension labels in "
+                             + "formats \"Architectural\" or \"Engineering\". "
+                             + "Format changed to \"Decimal\"."));
 };
 
 /**
