@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -390,6 +390,13 @@ SvgImporter.prototype.importShape = function(shape) {
         }
     }
 
+    // auto convert splines into lines / arcs if appropriate:
+    if (isSplineShape(shape)) {
+        if (RSettings.getBoolValue("SvgImport/AutoConvertSplines", true)===true) {
+            shape = ShapeAlgorithms.splineToLineOrArc(shape, RSettings.getDoubleValue("SvgImport/AutoConvertSplinesTolerance", 0.01));
+        }
+    }
+
     var entity = shapeToEntity(this.getDocument(), shape);
 
     if (isNull(entity)) {
@@ -446,15 +453,16 @@ SvgImporter.prototype.importBezier = function(x1, y1, px1, py1, px2, py2, x2, y2
     spline.appendControlPoint(new RVector(px2, py2));
     spline.appendControlPoint(new RVector(x2, y2));
 
-    var shape;
-    if (RSettings.getBoolValue("SvgImport/AutoConvertSplines", true)===true) {
-        shape = ShapeAlgorithms.splineToLineOrArc(spline, 0.1);
-    }
-    else {
-        shape = spline;
-    }
+//    var shape;
+//    if (RSettings.getBoolValue("SvgImport/AutoConvertSplines", true)===true) {
+//        shape = ShapeAlgorithms.splineToLineOrArc(spline, 0.1);
+//    }
+//    else {
+//        shape = spline;
+//    }
+//    this.importShape(shape);
 
-    this.importShape(shape);
+    this.importShape(spline);
 };
 
 SvgImporter.prototype.importBezier2 = function(x1, y1, px, py, x2, y2) {
